==> clutter_0.8.0.orig.tar.gz: clutter-0.8.0/clutter/clutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CLUTTER_ENUM_TYPES_H__
#define __CLUTTER_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./clutter-actor.h" */
GType clutter_actor_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_FLAGS (clutter_actor_flags_get_type())

/* enumerations from "./clutter-event.h" */
GType clutter_modifier_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_MODIFIER_TYPE (clutter_modifier_type_get_type())

GType clutter_event_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_FLAGS (clutter_event_flags_get_type())

GType clutter_event_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_TYPE (clutter_event_type_get_type())

GType clutter_scroll_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_DIRECTION (clutter_scroll_direction_get_type())

GType clutter_stage_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STAGE_STATE (clutter_stage_state_get_type())

/* enumerations from "./clutter-feature.h" */
GType clutter_feature_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FEATURE_FLAGS (clutter_feature_flags_get_type())

/* enumerations from "./clutter-main.h" */
GType clutter_init_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INIT_ERROR (clutter_init_error_get_type())

/* enumerations from "./clutter-script.h" */
GType clutter_script_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCRIPT_ERROR (clutter_script_error_get_type())

/* enumerations from "./clutter-shader.h" */
GType clutter_shader_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_ERROR (clutter_shader_error_get_type())

/* enumerations from "./clutter-texture.h" */
GType clutter_texture_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_ERROR (clutter_texture_error_get_type())

GType clutter_texture_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_FLAGS (clutter_texture_flags_get_type())

GType clutter_texture_quality_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_QUALITY (clutter_texture_quality_get_type())

/* enumerations from "./clutter-timeline.h" */
GType clutter_timeline_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TIMELINE_DIRECTION (clutter_timeline_direction_get_type())

/* enumerations from "./clutter-types.h" */
GType clutter_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAVITY (clutter_gravity_get_type())

GType clutter_rotate_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_AXIS (clutter_rotate_axis_get_type())

GType clutter_rotate_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_DIRECTION (clutter_rotate_direction_get_type())

GType clutter_request_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REQUEST_MODE (clutter_request_mode_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */

==> clutter-0.9_0.9.2.orig.tar.gz: clutter-0.9.2/clutter/clutter-enum-types.h <==

/* Generated data (by glib-mkenums) */

#ifndef __CLUTTER_ENUM_TYPES_H__
#define __CLUTTER_ENUM_TYPES_H__

#include <glib-object.h>

G_BEGIN_DECLS

/* enumerations from "./clutter-actor.h" */
GType clutter_actor_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ACTOR_FLAGS (clutter_actor_flags_get_type())

/* enumerations from "./clutter-event.h" */
GType clutter_modifier_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_MODIFIER_TYPE (clutter_modifier_type_get_type())

GType clutter_event_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_FLAGS (clutter_event_flags_get_type())

GType clutter_event_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_EVENT_TYPE (clutter_event_type_get_type())

GType clutter_scroll_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCROLL_DIRECTION (clutter_scroll_direction_get_type())

GType clutter_stage_state_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_STAGE_STATE (clutter_stage_state_get_type())

/* enumerations from "./clutter-feature.h" */
GType clutter_feature_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FEATURE_FLAGS (clutter_feature_flags_get_type())

/* enumerations from "./clutter-main.h" */
GType clutter_init_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_INIT_ERROR (clutter_init_error_get_type())

/* enumerations from "./clutter-path.h" */
GType clutter_path_node_type_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_PATH_NODE_TYPE (clutter_path_node_type_get_type())

/* enumerations from "./clutter-script.h" */
GType clutter_script_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SCRIPT_ERROR (clutter_script_error_get_type())

/* enumerations from "./clutter-shader.h" */
GType clutter_shader_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_SHADER_ERROR (clutter_shader_error_get_type())

/* enumerations from "./clutter-texture.h" */
GType clutter_texture_error_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_ERROR (clutter_texture_error_get_type())

GType clutter_texture_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_FLAGS (clutter_texture_flags_get_type())

GType clutter_texture_quality_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TEXTURE_QUALITY (clutter_texture_quality_get_type())

/* enumerations from "./clutter-timeline.h" */
GType clutter_timeline_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_TIMELINE_DIRECTION (clutter_timeline_direction_get_type())

/* enumerations from "./clutter-types.h" */
GType clutter_gravity_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_GRAVITY (clutter_gravity_get_type())

GType clutter_rotate_axis_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_AXIS (clutter_rotate_axis_get_type())

GType clutter_rotate_direction_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ROTATE_DIRECTION (clutter_rotate_direction_get_type())

GType clutter_request_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_REQUEST_MODE (clutter_request_mode_get_type())

GType clutter_animation_mode_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_ANIMATION_MODE (clutter_animation_mode_get_type())

GType clutter_font_flags_get_type (void) G_GNUC_CONST;
#define CLUTTER_TYPE_FONT_FLAGS (clutter_font_flags_get_type())

G_END_DECLS

#endif /* !__CLUTTER_ENUM_TYPES_H__ */

/* Generated data ends here */
